@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-06 23:17:54
-:LastEditTime: 2021-11-03 16:09:14
+:LastEditTime: 2022-04-08 16:19:35
 :LastEditors: ChenXiaolei
 :Description: 数据库基础操作类
 """
@@ -211,7 +211,7 @@ class BaseModel:
             return list_row['count']
         return 0
 
-    def del_entity(self, where, params=None):
+    def del_entity(self, where, params=None, limit=""):
         """
         :Description: 根据条件删除数据库中的数据
         :param where: 数据库查询条件语句
@@ -220,8 +220,11 @@ class BaseModel:
         :last_editors: ChenXiaolei
         """
         if where:
-            where = " WHERE " + where
-            sql = "DELETE FROM " + self.table_name + where
+            where = "WHERE " + where
+            if limit and limit.lower().find("limit")<0:
+                limit = f"LIMIT {limit}"
+
+            sql = f"DELETE FROM {self.table_name} {where} {limit}"
 
             if self.is_transaction():
                 transaction_item = {}
@@ -572,7 +575,7 @@ class BaseModel:
                 return False
         return True
 
-    def update_table(self, update_sql, where, params=None):
+    def update_table(self, update_sql, where, params=None, limit=""):
         """
         :Description: 更新数据表
         :param update_sql: 更新set语句
@@ -583,7 +586,12 @@ class BaseModel:
         """
         if where and where.strip() != '':
             where = " WHERE " + where
-        sql = f"UPDATE {self.table_name} SET {update_sql}{where};"
+
+        if limit and limit.lower().find("limit")<0:
+            limit = f"LIMIT {limit}"
+
+        sql = f"UPDATE {self.table_name} SET {update_sql}{where} {limit};"
+
         if self.is_transaction():
             transaction_item = {}
             transaction_item["sql"] = sql
@@ -597,7 +605,7 @@ class BaseModel:
             else:
                 return False
 
-    def get_dict(self, where='', group_by='', order_by='', limit='', field="*", params=None):
+    def get_dict(self, where='', group_by='', order_by='', limit='1', field="*", params=None):
         """
         :Description: 返回字典dict
         :param where: 数据库查询条件语句
@@ -617,7 +625,7 @@ class BaseModel:
             order_by = " ORDER BY " + order_by
         if limit:
             limit = " LIMIT "+str(limit)
-        sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit}"
+        sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit};"
         one_row = self.db.fetch_one_row(sql, params)
         return one_row  # self.__row_entity(list_row)
 
