@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-04-16 14:38:22
-:LastEditTime: 2020-12-25 09:53:40
+:LastEditTime: 2021-04-21 12:03:16
 :LastEditors: ChenXiaolei
 :Description: 加密帮助类
 """
@@ -119,17 +119,17 @@ class CryptoHelper:
         """
         :Description: base64加密
         :param source: 需加密的字符串
-        :return: 加密后的字符串
+        :return: 加密后的bytes
         :last_editors: ChenXiaolei
         """
         if not source.strip():
             return ""
         import base64
         encode_string = base64.b64encode(source.encode(encoding=encoding))
-        return encode_string
+        return encode_string.decode(encoding=encoding)
 
     @classmethod
-    def base64_decode(self, source):
+    def base64_decode(self, source, encoding="utf-8"):
         """
         :Description: base64解密
         :param source: 需加密的字符串
@@ -140,7 +140,7 @@ class CryptoHelper:
             return ""
         import base64
         decode_string = base64.b64decode(source)
-        return decode_string
+        return decode_string.decode(encoding=encoding)
 
     @classmethod
     def _aes_pad(self, text, encoding="utf-8"):
