@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-05-19 10:33:52
-:LastEditTime: 2021-05-21 15:55:39
+:LastEditTime: 2022-01-18 19:24:56
 :LastEditors: ChenXiaolei
 :Description: ufile传输
 """
@@ -1009,7 +1009,7 @@ class BOSHelper():
     ACCESS_KEY_ID = ""
     SECRET_ACCESS_KEY = ""
 
-    def __init__(self, access_key_id, secret_access_key, bos_host, **other_config):
+    def __init__(self, access_key_id, secret_access_key, bos_host="bj.bcebos.com", bos_media_host="http://media.bj.baidubce.com", **other_config):
         """
         :description: 百度云存储(BOS)初始化
         :param access_key_id: 百度云后台密钥id
@@ -1023,6 +1023,8 @@ class BOSHelper():
         from baidubce.services import bos
         from baidubce.services.bos import canned_acl
         from baidubce.services.bos.bos_client import BosClient
+        from baidubce.services import media
+        from baidubce.services.media.media_client import MediaClient
 
         # 创建BceClientConfiguration
         self.bos_config = BceClientConfiguration(credentials=BceCredentials(
@@ -1030,6 +1032,10 @@ class BOSHelper():
         # 创建BOS客户端
         self.bos_client = BosClient(self.bos_config)
 
+        self.bos_media_config = BceClientConfiguration(credentials=BceCredentials(
+            access_key_id, secret_access_key), endpoint=bos_media_host, **other_config)
+        self.bos_media_client = MediaClient(self.bos_media_config)
+
     def get_file_info(self, bucket_name, object_name):
         """
         :description: 获取对象信息
@@ -1178,7 +1184,7 @@ class BOSHelper():
                                                        prefix=prefix,
                                                        delimiter=delimiter)
 
-            if not object_list or not hasattr(object_list,"contents") or len(
+            if not object_list or not hasattr(object_list, "contents") or len(
                     object_list.contents) == 0:
                 return objects, dirs
             for obj in object_list.contents:
@@ -1192,6 +1198,16 @@ class BOSHelper():
 
         return objects, dirs
 
+    def get_media_info(self, bucket_name, object_name):
+        """
+        :description: 百度云MCP音视频获取媒体信息
+        :param bucket_name: bucket名称
+        :param object_name: 表示不包含Bucket名称在内的Object的完整路径，例如example/folder/abc.jpg。
+        :return 媒体信息
+        :last_editors: ChenXiaolei
+        """        
+        return self.bos_media_client.get_mediainfo_of_file(bucket_name, object_name)
+
 
 class LocalFileHelper():
     """
@@ -1275,3 +1291,181 @@ class LocalFileHelper():
         :last_editors: ChenXiaolei
         """
         return os.path.exists(file_path)
+
+
+class S3Helper():
+    """
+    :description: AWS S3存储
+    :last_editors: ChenXiaolei
+    """
+
+    def __init__(self, aws_access_key_id, aws_secret_access_key, region_name, **other_config):
+        """
+        :description: AWS存储(BOS)初始化
+        :param access_key_id: AWS S后台密钥id
+        :param secret_access_key: AWS S3后台密钥key
+        :param region_name: 指定AWS S3存储节点host
+        :last_editors: ChenXiaolei
+        """
+        import boto3
+        session = boto3.session.Session(aws_access_key_id=aws_access_key_id,aws_secret_access_key=aws_secret_access_key,region_name=region_name)
+        self.s3_resource = session.resource('s3')
+        self.s3_client = session.client('s3')
+
+    def get_file_info(self, bucket_name, object_name):
+        """
+        :description: 获取对象信息
+        :param bucket_name: bucket名称
+        :param object_name: 表示下载的OSS文件的完整名称，即包含文件后缀在内的完整路径，例如abc/efg/123.jpg
+        :return 成功返回对象信息 失败则抛出异常
+        :last_editors: ChenXiaolei
+        """
+        try:
+            return self.s3_client.get_object(Bucket=bucket_name, Key=object_name)
+        except:
+            raise
+
+    def get_object(self, bucket_name, object_name):
+        """
+        :description: 获取对象数据流
+        :param bucket_name: bucket名称
+        :param object_name: 表示下载的OSS文件的完整名称，即包含文件后缀在内的完整路径，例如abc/efg/123.jpg
+        :return 对象数据流
+        :last_editors: ChenXiaolei
+        """
+        try:
+            return self.s3_client.download_fileobj(bucket_name, object_name)
+        except:
+            raise
+
+    def save_file(self, bucket_name, object_name, local_file):
+        """
+        :description: 将指定的OSS文件下载到本地文件
+        :param bucket_name: bucket名称
+        :param object_name: 表示下载的OSS文件的完整名称，即包含文件后缀在内的完整路径，例如abc/efg/123.jpg
+        :param local_file: 由本地文件路径加文件名包括后缀组成，例如/users/local/myfile.txt。
+        :return HTTP Response
+        :last_editors: ChenXiaolei
+        """
+
+        try:
+            return self.s3_client.download_file(bucket_name, object_name, local_file)
+        except:
+            raise
+
+    def put_file_from_file_path(self, bucket_name, object_name, local_file):
+        """
+        :description: 通过文件路径上传文件
+        :param bucket_name: bucket名称
+        :param object_name: 表示不包含Bucket名称在内的Object的完整路径，例如example/folder/abc.jpg。
+        :param local_file: 表示本地文件的完整路径，例如/users/local/abc.jpg。
+        :return 成功 True 异常抛出异常
+        :last_editors: ChenXiaolei
+        """
+        try:
+            self.s3_client.upload_file(
+                Bucket=bucket_name, Key=object_name, Filename=local_file)
+
+            return True
+        except:
+            raise
+
+    def put_file(self, bucket_name, object_name, source_file_object):
+        """
+        :description: 
+        :param bucket_name: bucket名称
+        :param object_name: 表示不包含Bucket名称在内的Object的完整路径，例如example/folder/abc.jpg。
+        :param source_file_object: 上传文件对象
+        :return 成功 True 其他异常
+        :last_editors: ChenXiaolei
+        """
+        try:
+            self.s3_client.upload_file(
+                Bucket=bucket_name, Key=object_name, Filename=source_file_object)
+
+            return True
+        except:
+            raise
+
+    def put_file_stream(self, bucket_name, object_name, data):
+        """
+        :description: 以数据流形式上传Object
+        :param bucket_name: bucket名称
+        :param object_name: 表示不包含Bucket名称在内的Object的完整路径，例如example/folder/abc.jpg。
+        :param data: file stream
+        :param content_length: 对象MD5值,计算方法是对数据执行md5算法获取128位二进制数据
+        :param content_md5: 对象MD5值
+        :return 成功 True 其他异常
+        :last_editors: ChenXiaolei
+        """
+        try:
+            self.s3_client.upload_fileobj(
+                Bucket=bucket_name, Key=object_name, Body=data)
+
+            return True
+        except:
+            raise
+
+    def del_file(
+        self,
+        bucket_name,
+        object_name,
+    ):
+        """
+        :Description: 删除文件
+        :param bucket_name: bucket名称
+        :param key_name: 存储对象名称
+        :return 成功True 失败抛出异常
+        :last_editors: ChenXiaolei
+        """
+        try:
+            self.s3_client.delete_object(bucket_name, object_name)
+            return True
+        except:
+            raise
+
+    # def multi_put_file(self, bucket_name, object_name, local_file, chunk_size=5, thread_num=multiprocessing.cpu_count()):
+    #     """
+    #     :description: 分片上传,自动计算分片
+    #     :param bucket_name: bucket名称
+    #     :param object_name: 表示不包含Bucket名称在内的Object的完整路径，例如example/folder/abc.jpg。
+    #     :param local_file: 表示本地文件的完整路径，例如/users/local/abc.jpg。
+    #     :return 成功True 失败抛出异常
+    #     :last_editors: ChenXiaolei
+    #     """
+
+    #     try:
+    #         self.s3_client.put_super_obejct_from_file(
+    #             bucket_name, object_name, local_file, chunk_size=chunk_size, thread_num=thread_num)
+    #     except:
+    #         raise
+
+    #     return True
+
+    def get_bucket_objects(self, bucket_name, prefix="", delimiter=""):
+        """
+        :description: 列举bucket下的文件和文件夹信息
+        :param bucket_name: bucket名称
+        :param prefix: bucket目录 例如"fun/"
+        :param delimiter: 对文件名称进行分组的字符 例如"/"
+        :return 文件列表，目录列表
+        :last_editors: ChenXiaolei
+        """
+
+        objects = []
+        dirs = []
+
+        try:
+            bucket = self.s3_resource.Bucket(bucket_name)
+            if not bucket.objects.all():
+                return objects, dirs
+            for obj in bucket.objects.all():
+                if obj.key.find('/') > -1 and obj.key.split(
+                        '/')[::2] not in dirs:
+                    dirs.append(obj.key.split('/')[::2])
+
+                objects.append(obj)
+        except:
+            raise
+
+        return objects, dirs
\ No newline at end of file
