@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-04-16 21:32:43
-:LastEditTime: 2021-03-16 17:17:09
+:LastEditTime: 2021-07-22 10:32:07
 :LastEditors: ChenXiaolei
 :Description: 日志帮助类
 """
@@ -14,6 +14,7 @@ import os
 import json
 import socket
 import platform
+import re
 
 from seven_framework.mysql import *
 from seven_framework.json import *
@@ -24,6 +25,7 @@ class Logger:
     指定保存日志的文件路径，日志级别，以及调用文件 将日志存入到指定的文件中
     级别优先级:NOTSET < DEBUG < INFO < WARNING < ERROR < CRITICAL
     """
+
     def __init__(self,
                  log_file_name,
                  log_level,
@@ -32,7 +34,7 @@ class Logger:
                  project_name=None,
                  log_config=None):
         """
-        :Description: 
+        :Description:
         :param log_file_name: 日志存储文件路径
         :param log_level: 日志等级
         :param logger: 日志标识
@@ -83,10 +85,27 @@ class Logger:
         self.logger.propagate = False
 
         # 创建handler，用于写入日志文件
-        self.handler_file = logging.handlers.TimedRotatingFileHandler(
-            log_file_name, 'D', 1, 10)
+        # 默认日志文件保存30个文件
+        backup_count = 30
+        # 日志文件备份时间统一设置
+        if log_config and "log_file_backup_count" in log_config and log_config["log_file_backup_count"]:
+            try:
+                backup_count = int(log_config["log_file_backup_count"])
+            except:
+                print(f"日志模块读取配置中log_file_backup_count值异常")
+        # 日志文件备份时间按照level设置(优先)
+        if log_config and f"log_file_backup_count_{log_level.lower()}" in log_config and log_config[f"log_file_backup_count_{log_level.lower()}"]:
+            try:
+                backup_count = int(
+                    log_config[f"log_file_backup_count_{log_level.lower()}"])
+            except:
+                print(f"日志模块读取配置中log_file_backup_count_{log_level.lower()}值异常")
+
+        self.handler_file = LoggerFileHandler(
+            log_file_name, 'D', 1, backupCount=backup_count,  encoding="utf-8")
         # 设置 切分后日志文件名的时间格式 默认 log_file_name+"." + suffix 如果需要更改需要改logging 源码
         self.handler_file.suffix = "%Y%m%d.log"
+        self.handler_file.extMatch = re.compile(r"^\d{4}\d{2}\d{2}.log$")
         self.handler_file.setLevel(logging_level)
 
         formatter = logging.Formatter(
@@ -115,13 +134,18 @@ class Logger:
                 pass
             else:
                 self.logger.addHandler(self.handler_file)
-            self.logger.addHandler(self.handler_console)
+            # 默认开启控制台日志
+            if not log_config or "log_console" not in log_config or log_config["log_console"]!=False:
+                self.logger.addHandler(self.handler_console)
 
         # 日志存储
         if storage and type(storage) == dict:
-            self.handler_storage = LoggerStorageHandler(
-                log_level, storage, project_name, host_ip)
-            self.logger.addHandler(self.handler_storage)
+            if "level_setting" in storage:
+                for level_item in storage["level_setting"]:
+                    if "level" in level_item and "storage" in level_item and log_level.lower() == level_item["level"].lower() and level_item["storage"] != False:
+                        self.handler_storage = LoggerStorageHandler(
+                            log_level, storage, project_name, host_ip)
+                        self.logger.addHandler(self.handler_storage)
 
     def close(self):
         if hasattr(self, "handler_file"):
@@ -148,6 +172,54 @@ class Logger:
         return logging.getLogger(loger_name)
 
 
+class LoggerFileHandler(logging.handlers.TimedRotatingFileHandler):
+
+    def emit(self, record):
+        """
+        :description: 重写文件日志记录方法
+        :param record: 日志信息
+        :return 无
+        :last_editors: ChenXiaolei
+        """
+        try:
+            log_info = {}
+            if hasattr(record, "extra") and record.extra:
+                for key in record.extra.keys():
+                    log_info[key] = record.extra[key]
+
+            format_dict = self.__merge_dict(
+                log_info, json.loads(self.formatter._fmt))
+
+            formatter = logging.Formatter(
+                JsonHelper.json_dumps(format_dict))
+            self.setFormatter(formatter)
+        except:
+            print("日志emit文件日志时异常时异常:" + traceback.format_exc())
+            pass
+        # 写入文件日志
+        try:
+            if self.shouldRollover(record):
+                self.doRollover()
+            logging.FileHandler.emit(self, record)
+        except Exception:
+            self.handleError(record)
+
+    @classmethod
+    def __merge_dict(self, *args):
+        """
+        :description: 合并多个字典 merge_dict(dict1,dict2,dict3)
+        :param args:不限个数的字典   
+        :return 合并后的字典
+        :last_editors: ChenXiaolei
+        """
+        result_dict = {}
+        for dict_item in args:
+            if type(dict_item) != dict:
+                continue
+            result_dict.update(dict_item)
+        return result_dict
+
+
 class LoggerStorageHandler(logging.Handler):
     def __init__(self, level, storage, project_name="", host_ip=""):
         if "engine" not in storage and "config" not in storage:
@@ -253,7 +325,12 @@ class LoggerStorageHandler(logging.Handler):
         level = record.levelname
         host_ip = self.host_ip
         record_time = int(record.created)
-        log_msg = record.message
+        if hasattr(record, "message"):
+            log_msg = record.message
+        elif hasattr(record, "msg"):
+            log_msg = record.msg
+        else:
+            log_msg = ""
 
         if self.storage_engine == "mysql":
             try:
@@ -274,7 +351,6 @@ class LoggerStorageHandler(logging.Handler):
         elif self.storage_engine == "redis":
             try:
                 log_info = {}
-                log_info["request_code"] = request_code
                 log_info["project_name"] = project_name
                 log_info["level"] = level
                 log_info["host_ip"] = host_ip
@@ -304,4 +380,4 @@ class LoggerStorageHandler(logging.Handler):
                 )
             except:
                 print("日志写入clickhouse异常:" + traceback.format_exc())
-                pass
\ No newline at end of file
+                pass
