@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-06 23:17:54
-:LastEditTime: 2021-06-24 17:00:16
+:LastEditTime: 2021-11-17 15:56:40
 :LastEditors: ChenXiaolei
 :Description: Handler基础类(api)
 """
@@ -33,7 +33,7 @@ class BaseApiHandler(BaseHandler):
             extra={"extra": {
                 "request_code": self.request_code if hasattr(self,"request_code") else ""
             }})
-        return self.reponse_json_error()
+        return self.response_json_error()
 
     def prepare_ext(self):
         """
