@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-06 23:17:54
-:LastEditTime: 2021-11-03 18:05:22
+:LastEditTime: 2022-04-07 14:20:59
 :LastEditors: ChenXiaolei
 :Description: Handler基础类
 """
@@ -544,7 +544,7 @@ def filter_check_params(must_params=None):
                 if json_params:
                     for field in json_params:
                         self.request_params[field] = json_params[field]
-            else:
+            if self.request.arguments and len(self.request.arguments)>0:
                 for field in self.request.arguments:
                     self.request_params[field] = self.get_param(field)
             if must_params:
@@ -594,7 +594,7 @@ def filter_check_sign(sign_key, sign_lower=False, reverse=False, is_sign_key=Fal
                     if json_params:
                         for field in json_params:
                             sign_params[field] = json_params[field]
-                else:
+                if self.request.arguments and len(self.request.arguments)>0:
                     for field in self.request.arguments:
                         sign_params[field] = self.get_param(field)
             else:
